@@ -4,13 +4,15 @@ import pytest
 from ipykernel.comm import Comm
 from ipywidgets import Widget
 
+
 class MockComm(Comm):
     """A mock Comm object.
 
     Can be used to inspect calls to Comm's open/send/close methods.
     """
-    comm_id = 'a-b-c-d'
-    kernel = 'Truthy'
+
+    comm_id = "a-b-c-d"
+    kernel = "Truthy"
 
     def __init__(self, *args, **kwargs):
         self.log_open = []
@@ -27,17 +29,20 @@ class MockComm(Comm):
     def close(self, *args, **kwargs):
         self.log_close.append((args, kwargs))
 
+
 _widget_attrs = {}
 undefined = object()
 
 
 @pytest.fixture
 def mock_comm():
-    _widget_attrs['_comm_default'] = getattr(Widget, '_comm_default', undefined)
+    _widget_attrs["_comm_default"] = getattr(Widget, "_comm_default", undefined)
     Widget._comm_default = lambda self: MockComm()
-    _widget_attrs['_ipython_display_'] = Widget._ipython_display_
+    _widget_attrs["_ipython_display_"] = Widget._ipython_display_
+
     def raise_not_implemented(*args, **kwargs):
         raise NotImplementedError()
+
     Widget._ipython_display_ = raise_not_implemented
 
     yield MockComm()
